==> svm-22.0.0-sources.jar: com/oracle/svm/truffle/api/SubstrateKnownTruffleTypes.java <==
/*
 * Copyright (c) 2019, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.truffle.api;

import org.graalvm.compiler.truffle.compiler.substitutions.KnownTruffleTypes;

import com.oracle.graal.pointsto.meta.AnalysisType;
import com.oracle.svm.core.heap.ReferenceInternals;
import com.oracle.svm.core.heap.Target_java_lang_ref_Reference;

import jdk.vm.ci.meta.MetaAccessProvider;
import jdk.vm.ci.meta.ResolvedJavaField;
import jdk.vm.ci.meta.ResolvedJavaType;

public final class SubstrateKnownTruffleTypes extends KnownTruffleTypes {

    public final ResolvedJavaField referentField = findField(lookupType(Target_java_lang_ref_Reference.class), ReferenceInternals.REFERENT_FIELD_NAME);

    public SubstrateKnownTruffleTypes(MetaAccessProvider metaAccess) {
        super(metaAccess);
    }

    @Override
    protected ResolvedJavaType lookupType(String className) {
        AnalysisType type = (AnalysisType) super.lookupType(className);
        type.registerAsReachable();
        return type;
    }

    @Override
    protected ResolvedJavaType lookupType(Class<?> c) {
        AnalysisType type = (AnalysisType) super.lookupType(c);
        type.registerAsReachable();
        return type;
    }
}

==> svm-23.0.1-sources.jar: com/oracle/svm/truffle/api/SubstrateKnownTruffleTypes.java <==
/*
 * Copyright (c) 2019, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.truffle.api;

import org.graalvm.compiler.truffle.compiler.substitutions.KnownTruffleTypes;

import com.oracle.graal.pointsto.meta.AnalysisType;
import com.oracle.svm.core.heap.ReferenceInternals;
import com.oracle.svm.core.heap.Target_java_lang_ref_Reference;

import jdk.vm.ci.meta.MetaAccessProvider;
import jdk.vm.ci.meta.ResolvedJavaField;
import jdk.vm.ci.meta.ResolvedJavaType;

public final class SubstrateKnownTruffleTypes extends KnownTruffleTypes {

    public final ResolvedJavaField referentField = findField(lookupType(Target_java_lang_ref_Reference.class), ReferenceInternals.REFERENT_FIELD_NAME);

    public SubstrateKnownTruffleTypes(MetaAccessProvider metaAccess) {
        super(metaAccess);
    }

    @Override
    protected ResolvedJavaType lookupType(String className) {
        AnalysisType type = (AnalysisType) super.lookupType(className);
        type.registerAsReachable("known Truffle type");
        return type;
    }

    @Override
    protected ResolvedJavaType lookupType(Class<?> c) {
        AnalysisType type = (AnalysisType) super.lookupType(c);
        type.registerAsReachable("known Truffle type");
        return type;
    }
}
